@@ -460,7 +460,8 @@ theme_create_preview (GdkColor *colors)
     gint width = 44;
     gint height = 22;
 
-    drawable = gdk_pixmap_new (NULL, width, height, 24);
+    drawable = gdk_pixmap_new (gdk_get_default_root_window(), width, height,
+                               gdk_drawable_get_depth (gdk_get_default_root_window ()));
     cr = gdk_cairo_create (drawable);
     cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
@@ -561,6 +562,9 @@ cb_hinting_style_combo_changed (GtkComboBox *combo)
 
     /* Save setting */
     xfconf_channel_set_string (xsettings_channel, "/Xft/HintStyle", xft_hint_styles_array[active]);
+
+    /* Also update /Xft/Hinting to match */
+    xfconf_channel_set_int (xsettings_channel, "/Xft/Hinting", active > 0 ? 1 : 0);
 }
 
 static void
@@ -664,7 +668,6 @@ appearance_settings_load_icon_themes (preview_data *pd)
     GtkIconTheme *icon_theme;
     GdkPixbuf    *preview;
     GdkPixbuf    *icon;
-    GError       *error = NULL;
     gchar*        preview_icons[4] = { "folder", "go-down", "audio-volume-high", "web-browser" };
     int           coords[4][2] = { { 4, 4 }, { 24, 4 }, { 4, 24 }, { 24, 24 } };
 
@@ -721,17 +724,13 @@ appearance_settings_load_icon_themes (preview_data *pd)
 
                     for (p = 0; p < 4; p++)
                     {
+                        icon = NULL;
                         if (gtk_icon_theme_has_icon (icon_theme, preview_icons[p]))
-                            icon = gtk_icon_theme_load_icon (icon_theme, preview_icons[p], 16, 0, &error);
-                        else
-                            icon = gtk_icon_theme_load_icon (icon_theme, "image-missing", 16, 0, &error);
+                            icon = gtk_icon_theme_load_icon (icon_theme, preview_icons[p], 16, 0, NULL);
+                        else if (gtk_icon_theme_has_icon (icon_theme, "image-missing"))
+                            icon = gtk_icon_theme_load_icon (icon_theme, "image-missing", 16, 0, NULL);
 
-                        if (!icon)
-                        {
-                            g_warning ("Couldn't load icon: %s", error->message);
-                            g_error_free (error);
-                        }
-                        else
+                        if (icon)
                         {
                             gdk_pixbuf_copy_area (icon, 0, 0, 16, 16, preview, coords[p][0], coords[p][1]);
                             g_object_unref (icon);
@@ -781,6 +780,7 @@ appearance_settings_load_icon_themes (preview_data *pd)
                         gtk_tree_path_free (tree_path);
                     }
 
+                    g_object_unref (icon_theme);
                     g_object_unref (preview);
                 }
             }
