@@ -351,7 +351,10 @@ xfce_displays_helper_finalize (GObject *object)
         gdk_error_trap_push ();
         XRRFreeScreenResources (helper->resources);
         gdk_flush ();
-        gdk_error_trap_pop ();
+        if (gdk_error_trap_pop () != 0)
+        {
+            g_critical ("Failed to free screen resources");
+        }
         helper->resources = NULL;
     }
 
@@ -408,10 +411,11 @@ xfce_displays_helper_screen_on_event (GdkXEvent *xevent,
 {
     XfceDisplaysHelper *helper = XFCE_DISPLAYS_HELPER (data);
     GPtrArray          *old_outputs;
-    XfceRRCrtc         *crtc;
+    XfceRRCrtc         *crtc = NULL;
     XfceRROutput       *output, *o;
     XEvent             *e = xevent;
     gint                event_num;
+    gint                j;
     guint               n, m, nactive = 0;
     gboolean            found = FALSE, changed = FALSE;
 
@@ -493,9 +497,37 @@ xfce_displays_helper_screen_on_event (GdkXEvent *xevent,
                 {
                     xfsettings_dbg (XFSD_DEBUG_DISPLAYS, "New output connected: %s",
                                     output->info->name);
+                    /* need to enable crtc for output ? */
+                    if (output->info->crtc == None)
+                    {
+                        xfsettings_dbg (XFSD_DEBUG_DISPLAYS, "enabling crtc for %s", output->info->name);
+                        crtc = xfce_displays_helper_find_usable_crtc (helper, output);
+                        if (crtc)
+                        {
+                            crtc->mode = output->preferred_mode;
+                            crtc->rotation = RR_Rotate_0;
+                            crtc->x = crtc->y = 0;
+                            /* set width and height */
+                            for (j = 0; j < helper->resources->nmode; ++j)
+                            {
+                                if (helper->resources->modes[j].id == output->preferred_mode)
+                                {
+                                    crtc->width = helper->resources->modes[j].width;
+                                    crtc->height = helper->resources->modes[j].height;
+                                    break;
+                                }
+                            }
+                            xfce_displays_helper_set_outputs (crtc, output);
+                            crtc->changed = TRUE;
+                        }
+                    }
+
                     changed = TRUE;
                 }
             }
+            if (changed)
+                xfce_displays_helper_apply_all (helper);
+
             /* Start the minimal dialog according to the user preferences */
             if (changed && xfconf_channel_get_bool (helper->channel, NOTIFY_PROP, FALSE))
                 xfce_spawn_command_line_on_screen (NULL, "xfce4-display-settings -m", FALSE,
@@ -695,9 +727,14 @@ xfce_displays_helper_load_from_xfconf (XfceDisplaysHelper *helper,
             rate = (gdouble) helper->resources->modes[m].dotClock /
                     ((gdouble) helper->resources->modes[m].hTotal * (gdouble) helper->resources->modes[m].vTotal);
 
+            /* construct a string equivalent to the mode generated in displays */
+            /* property is the resources mode translated into display panel name */
+            g_snprintf (property, sizeof (property), "%dx%d", helper->resources->modes[m].width,
+                        helper->resources->modes[m].height);
+
             /* find the mode corresponding to the saved values */
-            if (rint (rate) == rint (output_rate)
-                && (g_strcmp0 (helper->resources->modes[m].name, str_value) == 0))
+            if (rint (rate * 10) == rint (output_rate * 10)
+                && (g_strcmp0 (property, str_value) == 0))
             {
                 valid_mode = helper->resources->modes[m].id;
                 break;
@@ -842,6 +879,9 @@ xfce_displays_helper_list_outputs (XfceDisplaysHelper *helper)
         crtc = xfce_displays_helper_find_crtc_by_id (helper, output->info->crtc);
         output->active = crtc && crtc->mode != None;
 
+        /* Translate output->name into xfconf compatible format in place */
+        g_strcanon(output->info->name, "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_<>", '_');
+
         xfsettings_dbg (XFSD_DEBUG_DISPLAYS, "Detected output %lu %s.", output->id,
                         output->info->name);
 
@@ -863,8 +903,10 @@ xfce_displays_helper_free_output (XfceRROutput *output)
     gdk_error_trap_push ();
     XRRFreeOutputInfo (output->info);
     gdk_flush ();
-    gdk_error_trap_pop ();
-
+    if (gdk_error_trap_pop () != 0)
+    {
+        g_critical ("Failed to free output info");
+    }
     g_free (output);
 }
 
@@ -1207,7 +1249,10 @@ xfce_displays_helper_apply_all (XfceDisplaysHelper *helper)
     /* release the grab, changes are done */
     gdk_x11_display_ungrab (helper->display);
     gdk_flush ();
-    gdk_error_trap_pop ();
+    if (gdk_error_trap_pop () != 0)
+    {
+        g_critical ("Failed to apply display settings");
+    }
 }
 
 
